"""
Module to include the functionality related to the
parameters and how we define them to be used in our
'yta-editor' video editor library.
"""
from yta_editor_parameters.constant import ConstantVideoEditorParameter
from yta_editor_parameters.eased import EasedVideoEditorParameter


__all__ = [
    'ConstantVideoEditorParameter',
    'EasedVideoEditorParameter'
]